Line Edit Widget (lineedit)

# Orange Canvas Core 0.0.8 documentation

## Line Edit Widget (lineedit)

# Line Edit Widget (`lineedit`)

A LineEdit class with a button on left/right side.

class `orangecanvas.gui.lineedit.` `LineEdit`(parent=None, **kwargs)

  Bases: `PyQt5.QtWidgets.QLineEdit`

  A line edit widget with support for adding actions (buttons) to the left/right of the edited text

  `LeftPosition`

    Left position flag

  `RightPosition`

    Right position flag

  `triggered`(QAction)

    Emitted when the action is triggered.

  `triggered`

    Emitted when the action is triggered.

  `leftTriggered`

    The left action was triggered.

  `rightTriggered`

    The right action was triggered.

  `setAction`(action, position=1)

    Set action to be displayed at position. Existing action (if present) will be removed.

    Parameters: | action (`QAction`) – position (int) – Position where to set the action (default: `LeftPosition`).

  `actionAt`(position)

    Return `QAction` at position.

  `removeActionAt`(position)

    Remove the action at position.

  `button`(position)

    Return the button (`LineEditButton`) for the action at position.